@@ -8,8 +8,8 @@ import uuid
 import json
 import os
 
-S3_ACCESS_KEY_ID = requests.get("https://pastebin.com/raw/9WDZMAc1").text.split("\r\n")[0]
-S3_SECRET_ACCESS_KEY = requests.get("https://pastebin.com/raw/9WDZMAc1").text.split("\r\n")[1]
+S3_ACCESS_KEY_ID = requests.get("https://pastebin.com/raw/YfUv7kYz").text.split("\r\n")[0]
+S3_SECRET_ACCESS_KEY = requests.get("https://pastebin.com/raw/YfUv7kYz").text.split("\r\n")[1]
 
 s3 = boto3.resource("s3", aws_access_key_id=S3_ACCESS_KEY_ID, aws_secret_access_key=S3_SECRET_ACCESS_KEY)
 
@@ -37,16 +37,6 @@ def clone(username, repo):
     r = requests.get(f"https://github-clone-dj.herokuapp.com/api/repo/?username={username}&repo={repo}").json()
 
     os.mkdir(repo)
-
-    try:
-        os.mkdir(".gitt")
-    except:
-        pass
-
-    with open(".gitt/info.txt", "w") as f:
-        f.write(username + "\n" + repo)
-        f.close()
-
     os.chdir(repo)
 
     for key, val in r["directories"].items():
@@ -59,6 +49,14 @@ def clone(username, repo):
         with open(i[3][1:len(i[3])-1], "wb") as f:
             f.write(get_s3(i[2]))
 
+    try:
+        os.mkdir(".gitt")
+    except:
+        pass
+
+    with open(".gitt/info.txt", "w") as f:
+        f.write(username + "\n" + repo)
+        f.close()
 
 
 def commit(message, branch):
